@@ -60,16 +60,20 @@ Example:
         return module in modules
 
     def get_all_permissions(self):
-        result = []
 
-        perms = self.get('permissions', [])
-        if self.get('groups'):
-            rows = self._db.view('_all_docs', keys=self.groups, include_docs=True).rows
-            for row in rows:
-                perms.extend(row.doc.permissions)
+        if not hasattr(self, '_permissions'):
+            # cache permissions
 
-        return set(perms)
+            perms = self.get('permissions', [])[:]  # copy perms
+            if self.get('groups'):
+                rows = self._db.view('_all_docs', keys=self.groups, include_docs=True).rows
+                for row in rows:
+                    perms.extend(row.doc.permissions)
 
+            self._permissions = set(perms)
+
+
+        return self._permissions
 
 
 
